<a href='https://colab.research.google.com/drive/12adhXXF1MQIzh_vEwKX9r_iF6jV-CNHE#scrollTo=N2_uubn_2qGM' target='_blank'>

![image](https://github.com/user-attachments/assets/349a4052-66e9-4cdf-a773-b06425485bd1)

</a>

# LogMD:  Share MD While It Runs 
 <a href="https://colab.research.google.com/drive/12adhXXF1MQIzh_vEwKX9r_iF6jV-CNHE#scrollTo=N2_uubn_2qGM" target="_blank" rel="noopener noreferrer"><img src="https://colab.research.google.com/assets/colab-badge.svg" alt="Open In Colab"></a> 
[![Buy us a coffee](https://img.shields.io/badge/Buy%20us%20a%20coffee-%23FF813F?style=flat-square&logo=buymeacoffee&logoColor=white)](https://studio.buymeacoffee.com/auth/oauth_callback?is_signup=)
[![Reach Out](https://img.shields.io/badge/Reach%20Out-%2300AEEF?style=flat-square&logo=telegram&logoColor=white)](https://calendly.com/alexander-mathiasen/vchat)



```shell
pip install logmd
```

Try in this <img src="https://colab.research.google.com/assets/colab-badge.svg" alt="Open In Colab"></a> or `logmd upload 1crn.pdb` from the terminal.

We support [Atomic Simulation Environment (ASE)](https://wiki.fysik.dtu.dk/ase/) and [OpenMM](https://github.com/openmm/openmm) - [vote here](https://github.com/log-md/logmd/issues/1) for other backends.

